# PyAudioMixer

Audio mixing simplified. This library will allow you to play audio on top of other audio tracks as well as modify those audio data to your likings via callbacks. This is a project made specifically for Mantra AI and there are currently no plans for a full blown documentation other than the docstrings.

## Requirements

- FFmpeg (For format conversions (i.e., .mp4 to .wav))
